ExAws.Dynamo.Encodable protocol

Summary

encode(value)

Converts an elixir value into a map tagging the value with its dynamodb type

Types

t :: term

Functions

encode(value)

Converts an elixir value into a map tagging the value with its dynamodb type