ExAws.Dynamo.Decoder
Converts from the dynamo type spec into more native elixir types
Summary↑
| binary_map_to_struct(bmap, module) | |
| binary_to_number(binary) | |
| decode(arg1) | Convert dynamo format to elixir |
| decode(item, list2) | Decodes a dynamo response into a struct |
| decode_collection(items, list2) | Convenience function, see decode/2 |
Functions
Convert dynamo format to elixir
Functions which convert the dynamo style values into normal elixir values. Use these if you just want the dynamo result to look more like elixir without coercing it into a particular struct.
Decodes a dynamo response into a struct.
If Dynamo.Decodable is implimented for the struct it will be called after the completion of the coercion.
This is important for handling nested maps if you wanted the nested maps to have atom keys.
Convenience function, see decode/2