ex_aws v0.0.3
Modules summary ↑
| ExAws | |
| ExAws.Actions | |
| ExAws.Config | |
| ExAws.Dynamo | |
| ExAws.Dynamo.Actions | |
| ExAws.Dynamo.Adapter | The purpose of this module is to surface the ExAws.Dynamo API with a single configuration chosen, such that it does not need passed in with every request |
| ExAws.Dynamo.Decoder | Converts from the dynamo type spec into more native elixir types |
| ExAws.Dynamo.Encoder | |
| ExAws.Dynamo.Lazy | Dynamo has a few functions that require paging. These functions operate just like those in ExAws.Dynamo, Except that they return streams instead of lists that can be iterated through and will automatically retrieve additional pages as necessary |
| ExAws.JSON.Codec | |
| ExAws.Kinesis | |
| ExAws.Kinesis.Actions | |
| ExAws.Kinesis.Adapter | The purpose of this module is to surface the ExAws.Kinesis API with a single configuration chosen, such that it does not need passed in with every request |
| ExAws.Kinesis.Lazy | Kinesis has a few functions that require paging. These functions operate just like those in Kinesis, except that they return streams instead of lists that can be iterated through and will automatically retrieve additional pages as necessary |
| ExAws.Request | |
| ExAws.Request.HttpClient | |
| Mix.Tasks.Kinesis.Tail | Tails a Stream |
Exceptions summary ↑
| ExAws.Dynamo.Encodable.TypeError |
Protocols summary ↑
| ExAws.Dynamo.Decodable |
| ExAws.Dynamo.Encodable |